"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Settings_1 = require("./Settings");
const SpellingDictionary_1 = require("./SpellingDictionary");
const util = require("./util/util");
const Rx = require("rxjs/Rx");
function traceWords(words, settings) {
    const r = Rx.Observable.from(words)
        .map(word => ({ word, config: settings }))
        .flatMap(async ({ word, config }) => {
        const settings = Settings_1.finalizeSettings(config);
        const dictionaries = (settings.dictionaries || [])
            .concat((settings.dictionaryDefinitions || []).map(d => d.name))
            .filter(util.uniqueFn);
        const dictSettings = Object.assign({}, settings, { dictionaries });
        const dicts = await SpellingDictionary_1.getDictionary(dictSettings);
        return { word, config, dicts };
    })
        .flatMap(({ word, config, dicts }) => {
        return dicts.dictionaries.map(dict => ({
            word,
            found: dict.has(word),
            dictName: dict.name,
            dictSource: dict.source,
            configSource: config.name || '',
        }));
    });
    return r;
}
exports.traceWords = traceWords;
//# sourceMappingURL=trace.js.map